"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Menu = void 0;

var _react = _interopRequireDefault(require("react"));

var _View = _interopRequireDefault(require("../../primitives/View"));

var _hooks = require("../../../hooks");

var _core = require("../../../core");

var _focus = require("@react-native-aria/focus");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//@ts-ignore - Todo - fix types to typings in rn-aria in next version
const Menu = /*#__PURE__*/_react.default.memo(({
  trigger,
  closeOnSelect = true,
  children,
  onOpen,
  onClose,
  ...props
}) => {
  let triggerRef = _react.default.useRef();

  const newProps = (0, _hooks.useThemeProps)('Menu', props);

  let [isOpen, toggle] = _react.default.useState(false);

  const {
    setPopover,
    closePopover
  } = (0, _core.usePopover)();

  const closeMenu = () => {
    closePopover();
    toggle(false);
    onClose && onClose();
  };

  const openMenu = () => {
    setPopover( /*#__PURE__*/_react.default.createElement(_View.default, newProps, /*#__PURE__*/_react.default.createElement(_focus.FocusScope, {
      restoreFocus: true,
      autoFocus: true
    }, children)), {
      triggerRef,
      animationDuration: 200,
      onClose: closeMenu,
      parentComponentConfig: {
        open: isOpen,
        closeMenu,
        closeOnSelect
      }
    });
    toggle(true);
    onOpen && onOpen();
  };

  return trigger({
    onPress: openMenu,
    ref: triggerRef
  }, {
    open: isOpen
  });
});

exports.Menu = Menu;
//# sourceMappingURL=Menu.js.map