"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.ListIcon = exports.ListItem = exports.Ul = exports.Ol = void 0;

var _react = _interopRequireDefault(require("react"));

var _Stack = require("../Stack");

var _Box = _interopRequireDefault(require("../Box"));

var _Text = _interopRequireDefault(require("../Text"));

var _Icon = _interopRequireDefault(require("../Icon"));

var _theme = require("../../../theme");

var _hooks = require("../../../hooks");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function findProps(props) {
  let [textProps, remaining] = _theme.themeTools.extractInObject(props, ['fontWeight', 'fontSize', 'textDecorationLine', 'color']);

  let [borderProps, otherRemainingProps] = _theme.themeTools.extractInObject(remaining, ['border', 'borderBottom', 'borderTop', 'borderLeft', 'borderRight', 'borderWidth', 'borderRadius', 'borderColor', 'borderRightColor', 'borderBottomWidth', 'borderLeftWidth', 'borderTopWidth', 'borderBotttomWidth', 'borderTopLeftRadius', 'borderBottomColor', 'borderBottomEndRadius', 'borderBottomLeftRadius', 'borderBottomRightRadius', 'borderBottomStartRadius', 'borderBottomWidth', 'borderEndColor', 'borderLeftColor', 'borderLeftWidth', 'borderRadius', 'borderRightWidth', 'borderStartColor', 'borderTopColor', 'borderTopEndRadius', 'borderTopLeftRadius', 'borderTopRightRadius', 'borderTopStartRadius', 'borderTopWidth']);

  let [layoutProps, remainingProps] = _theme.themeTools.extractInObject(otherRemainingProps, ['m', 'margin', 'mt', 'marginTop', 'mr', 'marginRight', 'mb', 'marginBottom', 'ml', 'marginLeft', 'mx', 'marginX', 'my', 'marginY', 'left', 'top', 'bottom', 'right', 'position', 'minH', 'minHeight', 'minWidth', 'minW', 'height', 'width']);

  return [textProps, remainingProps, layoutProps, borderProps];
}

const List = ({
  style,
  children,
  spacing,
  ...props
}) => {
  const themeProps = (0, _hooks.useThemeProps)('List', props); // add props to children

  let childrenArray = _react.default.Children.toArray(children);

  children = _react.default.Children.map(children, (child, ind) => {
    if (ind === childrenArray.length - 1) {
      return /*#__PURE__*/_react.default.cloneElement(child, {
        index: ind,
        ...themeProps.lastListItemStyle,
        ...props,
        py: spacing
      }, child.props.children);
    }

    return /*#__PURE__*/_react.default.cloneElement(child, {
      index: ind,
      ...props,
      py: spacing
    }, child.props.children);
  });
  let [, remainingProps, layoutProps, borderProps] = findProps(props);
  return /*#__PURE__*/_react.default.createElement(_Box.default, _extends({
    style: style
  }, themeProps.listStyle, layoutProps, borderProps), /*#__PURE__*/_react.default.createElement(_Stack.VStack, remainingProps, children));
};

const Ol = ({
  style,
  children,
  spacing,
  ...props
}) => {
  // add props to children
  let childrenArray = _react.default.Children.toArray(children);

  const themeProps = (0, _hooks.useThemeProps)('List', props);
  children = _react.default.Children.map(children, (child, ind) => {
    if (ind === childrenArray.length - 1) {
      return /*#__PURE__*/_react.default.cloneElement(child, {
        index: ind,
        ...themeProps.lastListItemStyle,
        ...child.props,
        ...props,
        ol: true,
        py: spacing
      }, child.props.children);
    }

    return /*#__PURE__*/_react.default.cloneElement(child, {
      index: ind,
      ...child.props,
      ...props,
      ol: true,
      py: spacing
    }, child.props.children);
  });
  let [, remainingProps, layoutProps, borderProps] = findProps(props);
  return /*#__PURE__*/_react.default.createElement(_Box.default, _extends({
    style: style
  }, layoutProps, themeProps.listStyle, borderProps), /*#__PURE__*/_react.default.createElement(_Stack.VStack, remainingProps, children));
};

exports.Ol = Ol;

const Ul = ({
  style,
  children,
  spacing,
  ...props
}) => {
  // add props to children
  const themeProps = (0, _hooks.useThemeProps)('List', props);

  let childrenArray = _react.default.Children.toArray(children);

  children = _react.default.Children.map(children, (child, ind) => {
    if (ind === childrenArray.length - 1) {
      return /*#__PURE__*/_react.default.cloneElement(child, {
        index: ind,
        ...themeProps.lastListItemStyle,
        ...props,
        ul: true,
        py: spacing
      }, child.props.children);
    }

    return /*#__PURE__*/_react.default.cloneElement(child, {
      index: ind,
      ...props,
      ul: true,
      py: spacing
    }, child.props.children);
  });
  let [, remainingProps, layoutProps, borderProps] = findProps(props);
  return /*#__PURE__*/_react.default.createElement(_Box.default, _extends({
    style: style
  }, themeProps.listStyle, layoutProps, borderProps), /*#__PURE__*/_react.default.createElement(_Stack.VStack, remainingProps, children));
};

exports.Ul = Ul;

const ListItem = /*#__PURE__*/_react.default.memo(({
  children,
  ...props
}) => {
  const themeProps = (0, _hooks.useThemeProps)('List', props);
  let [textProps, remainingProps,, borderProps] = findProps(props);
  const startNum = remainingProps.start ? remainingProps.start : 1; // Ordered list starting number

  return /*#__PURE__*/_react.default.createElement(_Box.default, _extends({
    flexDirection: "row",
    alignItems: "center"
  }, themeProps.listItemStyle, borderProps), /*#__PURE__*/_react.default.createElement(_Box.default, _extends({
    flexDirection: "row",
    alignItems: "center"
  }, remainingProps, {
    pl: 2
  }), remainingProps.unordered || remainingProps.ul ?
  /*#__PURE__*/
  //Adding disc in front of ListItem
  _react.default.createElement(_Text.default, _extends({}, themeProps.listItemNumberingStyle, textProps, {
    style: {
      transform: [{
        scale: 1.5
      }]
    }
  }), "\u2022") : null, remainingProps.ordered || remainingProps.ol ?
  /*#__PURE__*/
  //Adding index number in front of ListItem
  _react.default.createElement(_Text.default, _extends({
    mr: 2,
    fontWeight: "bold"
  }, textProps), remainingProps.index + startNum + '.') : null), /*#__PURE__*/_react.default.createElement(_Box.default, _extends({
    flexDirection: "row",
    alignItems: "center"
  }, themeProps.listItemTextStyle, remainingProps, textProps), children));
});

exports.ListItem = ListItem;

const ListIcon = /*#__PURE__*/_react.default.memo(props => {
  return /*#__PURE__*/_react.default.createElement(_Icon.default, _extends({
    mr: 2
  }, props));
});

exports.ListIcon = ListIcon;

var _default = /*#__PURE__*/_react.default.memo(List);

exports.default = _default;
//# sourceMappingURL=index.js.map