"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getCoordinates = getCoordinates;

var _reactNative = require("react-native");

function getCoordinates(elementTop, elementLeft, elementWidth, elementHeight, triggerWidth, triggerHeight, placeOverTriggerElement = true) {
  let top = elementTop;
  let left = elementLeft;
  const {
    isRTL
  } = _reactNative.I18nManager;

  const dimensions = _reactNative.Dimensions.get('window');

  const {
    width: windowWidth
  } = dimensions;
  const windowHeight = dimensions.height - (_reactNative.StatusBar.currentHeight || 0);
  const triggerIndent = !placeOverTriggerElement ? triggerHeight : 0;

  if (isRTL && left + triggerWidth > elementWidth || !isRTL && left + elementWidth > windowWidth) {
    left = Math.min(windowWidth - elementWidth, left + triggerWidth);
  } // Flip by Y axis if element hits bottom screen border


  if (top > windowHeight - elementHeight) {
    top = Math.min(windowHeight - elementHeight - triggerHeight - triggerIndent, top + triggerIndent);
  } else {
    top += triggerIndent;
  }

  const elementContainerStyle = {
    top,
    // Switch left to right for rtl devices
    ...(isRTL ? {
      right: left
    } : {
      left
    })
  };
  return elementContainerStyle;
}
//# sourceMappingURL=utils.js.map