import React from 'react';
import remove from 'lodash/remove';
import Box from '../../primitives/Box';
import { useThemeProps } from '../../../hooks';
import getIndexedChildren from '../../../utils/getIndexedChildren';
import { default as AccordionItem } from './AccordionItem';
import { default as AccordionSummary } from './AccordionSummary';
import { default as AccordionDetails } from './AccordionDetails';
import { default as AccordionIcon } from './AccordionIcon';
import { AccordionContext } from './Context';

const Accordion = ({
  children,
  allowMultiple,
  allowToggle,
  onChange,
  ...props
}) => {
  const {
    index: pIndex,
    defaultIndex,
    ...newProps
  } = useThemeProps('Accordion', props);
  const [index, setIndex] = React.useState(pIndex || defaultIndex || []);

  const changeHandler = (isOpening, activeIndex) => {
    let indexCopy = index.map(i => i);

    if (allowToggle) {
      if (isOpening) {
        indexCopy.push(activeIndex);
        allowMultiple ? setIndex(indexCopy) : setIndex([activeIndex]);
      } else {
        setIndex(index.splice(index.indexOf(activeIndex), 1));
      }
    } else {
      if (isOpening) {
        indexCopy.push(activeIndex);
        allowMultiple ? setIndex(indexCopy) : setIndex([activeIndex]);
      } else {
        remove(indexCopy, n => n === activeIndex);
        setIndex(indexCopy);
      }
    }

    onChange && onChange(indexCopy);
  };

  return /*#__PURE__*/React.createElement(AccordionContext.Provider, {
    value: {
      index: index,
      changeHandler
    }
  }, /*#__PURE__*/React.createElement(Box, newProps, getIndexedChildren(children, 'AccordionItem')));
};

Accordion.Item = AccordionItem;
Accordion.Summary = AccordionSummary;
Accordion.Details = AccordionDetails;
Accordion.Icon = AccordionIcon;
export default Accordion;
//# sourceMappingURL=Accordion.js.map