function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { VStack } from '../Stack';
import Box from '../Box';
import Text from '../Text';
import { default as Icon } from '../Icon';
import { themeTools } from '../../../theme';
import { useThemeProps } from '../../../hooks';

function findProps(props) {
  let [textProps, remaining] = themeTools.extractInObject(props, ['fontWeight', 'fontSize', 'textDecorationLine', 'color']);
  let [borderProps, otherRemainingProps] = themeTools.extractInObject(remaining, ['border', 'borderBottom', 'borderTop', 'borderLeft', 'borderRight', 'borderWidth', 'borderRadius', 'borderColor', 'borderRightColor', 'borderBottomWidth', 'borderLeftWidth', 'borderTopWidth', 'borderBotttomWidth', 'borderTopLeftRadius', 'borderBottomColor', 'borderBottomEndRadius', 'borderBottomLeftRadius', 'borderBottomRightRadius', 'borderBottomStartRadius', 'borderBottomWidth', 'borderEndColor', 'borderLeftColor', 'borderLeftWidth', 'borderRadius', 'borderRightWidth', 'borderStartColor', 'borderTopColor', 'borderTopEndRadius', 'borderTopLeftRadius', 'borderTopRightRadius', 'borderTopStartRadius', 'borderTopWidth']);
  let [layoutProps, remainingProps] = themeTools.extractInObject(otherRemainingProps, ['m', 'margin', 'mt', 'marginTop', 'mr', 'marginRight', 'mb', 'marginBottom', 'ml', 'marginLeft', 'mx', 'marginX', 'my', 'marginY', 'left', 'top', 'bottom', 'right', 'position', 'minH', 'minHeight', 'minWidth', 'minW', 'height', 'width']);
  return [textProps, remainingProps, layoutProps, borderProps];
}

const List = ({
  style,
  children,
  spacing,
  ...props
}) => {
  const themeProps = useThemeProps('List', props); // add props to children

  let childrenArray = React.Children.toArray(children);
  children = React.Children.map(children, (child, ind) => {
    if (ind === childrenArray.length - 1) {
      return /*#__PURE__*/React.cloneElement(child, {
        index: ind,
        ...themeProps.lastListItemStyle,
        ...props,
        py: spacing
      }, child.props.children);
    }

    return /*#__PURE__*/React.cloneElement(child, {
      index: ind,
      ...props,
      py: spacing
    }, child.props.children);
  });
  let [, remainingProps, layoutProps, borderProps] = findProps(props);
  return /*#__PURE__*/React.createElement(Box, _extends({
    style: style
  }, themeProps.listStyle, layoutProps, borderProps), /*#__PURE__*/React.createElement(VStack, remainingProps, children));
};

export const Ol = ({
  style,
  children,
  spacing,
  ...props
}) => {
  // add props to children
  let childrenArray = React.Children.toArray(children);
  const themeProps = useThemeProps('List', props);
  children = React.Children.map(children, (child, ind) => {
    if (ind === childrenArray.length - 1) {
      return /*#__PURE__*/React.cloneElement(child, {
        index: ind,
        ...themeProps.lastListItemStyle,
        ...child.props,
        ...props,
        ol: true,
        py: spacing
      }, child.props.children);
    }

    return /*#__PURE__*/React.cloneElement(child, {
      index: ind,
      ...child.props,
      ...props,
      ol: true,
      py: spacing
    }, child.props.children);
  });
  let [, remainingProps, layoutProps, borderProps] = findProps(props);
  return /*#__PURE__*/React.createElement(Box, _extends({
    style: style
  }, layoutProps, themeProps.listStyle, borderProps), /*#__PURE__*/React.createElement(VStack, remainingProps, children));
};
export const Ul = ({
  style,
  children,
  spacing,
  ...props
}) => {
  // add props to children
  const themeProps = useThemeProps('List', props);
  let childrenArray = React.Children.toArray(children);
  children = React.Children.map(children, (child, ind) => {
    if (ind === childrenArray.length - 1) {
      return /*#__PURE__*/React.cloneElement(child, {
        index: ind,
        ...themeProps.lastListItemStyle,
        ...props,
        ul: true,
        py: spacing
      }, child.props.children);
    }

    return /*#__PURE__*/React.cloneElement(child, {
      index: ind,
      ...props,
      ul: true,
      py: spacing
    }, child.props.children);
  });
  let [, remainingProps, layoutProps, borderProps] = findProps(props);
  return /*#__PURE__*/React.createElement(Box, _extends({
    style: style
  }, themeProps.listStyle, layoutProps, borderProps), /*#__PURE__*/React.createElement(VStack, remainingProps, children));
};
export const ListItem = /*#__PURE__*/React.memo(({
  children,
  ...props
}) => {
  const themeProps = useThemeProps('List', props);
  let [textProps, remainingProps,, borderProps] = findProps(props);
  const startNum = remainingProps.start ? remainingProps.start : 1; // Ordered list starting number

  return /*#__PURE__*/React.createElement(Box, _extends({
    flexDirection: "row",
    alignItems: "center"
  }, themeProps.listItemStyle, borderProps), /*#__PURE__*/React.createElement(Box, _extends({
    flexDirection: "row",
    alignItems: "center"
  }, remainingProps, {
    pl: 2
  }), remainingProps.unordered || remainingProps.ul ?
  /*#__PURE__*/
  //Adding disc in front of ListItem
  React.createElement(Text, _extends({}, themeProps.listItemNumberingStyle, textProps, {
    style: {
      transform: [{
        scale: 1.5
      }]
    }
  }), "\u2022") : null, remainingProps.ordered || remainingProps.ol ?
  /*#__PURE__*/
  //Adding index number in front of ListItem
  React.createElement(Text, _extends({
    mr: 2,
    fontWeight: "bold"
  }, textProps), remainingProps.index + startNum + '.') : null), /*#__PURE__*/React.createElement(Box, _extends({
    flexDirection: "row",
    alignItems: "center"
  }, themeProps.listItemTextStyle, remainingProps, textProps), children));
});
export const ListIcon = /*#__PURE__*/React.memo(props => {
  return /*#__PURE__*/React.createElement(Icon, _extends({
    mr: 2
  }, props));
});
export default /*#__PURE__*/React.memo(List);
//# sourceMappingURL=index.js.map