import React, { useState, useEffect } from 'react';
import { HybridContext } from './../hybrid-overlay/Context';
export const useColorMode = () => {
  const {
    colorMode: context
  } = React.useContext(HybridContext);

  if (context === undefined) {
    throw new Error('useColorMode must be used within a NativeBaseProvider');
  }

  return context;
};
export function useColorModeValue(light, dark) {
  const {
    colorMode
  } = useColorMode();
  return colorMode === 'dark' ? dark : light;
}
export function useModeManager(initialColorMode, colorModeManager) {
  const [colorMode, setRawMode] = useState();

  async function setColorMode(val) {
    if (colorModeManager) {
      await colorModeManager.set(val);
    }

    setRawMode(val);
  } // For initial setting initial color mode from storage


  useEffect(() => {
    if (colorModeManager) {
      (async function getMode() {
        let value = await colorModeManager.get(initialColorMode);
        setRawMode(value);
      })();
    } else {
      setRawMode(initialColorMode);
    }
  }, [initialColorMode, colorModeManager]);
  return {
    colorMode,
    setColorMode
  };
}
//# sourceMappingURL=hooks.js.map